/*
 * Copyright (c) 2004, Adam VanderHook <acidos@users.sf.net>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice unmodified, this list of conditions, and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.bj.pfpro.gui.swing.panel;

import java.awt.Dimension;
import java.awt.event.ActionEvent;

import javax.swing.DefaultCellEditor;
import javax.swing.JComboBox;

import net.bj.pfpro.firewall.Firewall;
import net.bj.pfpro.gui.swing.table.RuleTableModel;
import net.bj.pfpro.gui.swing.toolbar.RuleToolBar;

/**
 * A panel for displaying firewall <code>Rule</code>'s.
 * 
 * @author acidos
 * @version $Id: RulePanel.java,v 1.4 2004/08/25 00:49:27 acidos Exp $
 * @see net.bj.pfpro.firewall.Rule
 */
public class RulePanel extends PfPanel {
	
	public RulePanel(Firewall firewall) {
		super(firewall, new RuleTableModel(firewall));

		// Layout
		this.setMinimumSize(new Dimension(400, 100));
		
		// Toolbar
		this.add(new RuleToolBar(this));
		
		getTable().setRowHeight(40);

		// Popup Menu
		getPopupMenu().add(createMenu("Insert rule above", "add-above"));
		getPopupMenu().add(createMenu("Insert rule below", "add-below"));
		getPopupMenu().add(createMenu("Add rule at bottom", "add"));
		getPopupMenu().add(createMenu("Remove", "del"));
		
		// Handle Options Editor
		String[] optionDat = { "pass", "block" };
		JComboBox cmbOption = new JComboBox(optionDat);
		getTable().getColumnModel().getColumn(1).setCellEditor(new DefaultCellEditor(cmbOption));
		
		// Handle Direction Editor
		String[] directionDat = { "in", "out", "all" };
		JComboBox cmbDirection = new JComboBox(directionDat);
		getTable().getColumnModel().getColumn(2).setCellEditor(new DefaultCellEditor(cmbDirection));
		
		// Handle State Selector
		String[] stateDat = { "", "keep", "modulate" };
		JComboBox cmbState = new JComboBox(stateDat);
		getTable().getColumnModel().getColumn(11).setCellEditor(new DefaultCellEditor(cmbState));
		
		// Finish
		addTable();
	}

	/* (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent e) {
		if("add".equals(e.getActionCommand())) {
			((RuleTableModel) getModel()).add();
		} else if("add-top".equals(e.getActionCommand())) {
			((RuleTableModel) getModel()).addTop();
		} else if("add-below".equals(e.getActionCommand())) {
			((RuleTableModel) getModel()).addBelow(getTable().getSelectedRow());
		} else if("add-above".equals(e.getActionCommand())) {
			((RuleTableModel) getModel()).addAbove(getTable().getSelectedRow());
		} else if("del".equals(e.getActionCommand())) {
			((RuleTableModel) getModel()).remove(getTable().getSelectedRow());
		}		
	}
	
}
