/*
 * Copyright (c) 2004, Adam VanderHook <acidos@users.sf.net>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice unmodified, this list of conditions, and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.bj.pfpro.gui.swing.panel;

import java.awt.Dimension;
import java.awt.event.ActionEvent;

import javax.swing.DefaultCellEditor;
import javax.swing.JComboBox;
import javax.swing.JLabel;

import net.bj.pfpro.firewall.Firewall;
import net.bj.pfpro.gui.swing.table.ScrubTableModel;
import net.bj.pfpro.gui.swing.toolbar.BasicToolBar;

/**
 * A panel for displaying <code>Scrub</code> declarations
 * 
 * @author acidos
 * @version $Id: ScrubPanel.java,v 1.4 2004/08/25 00:49:27 acidos Exp $
 * @see net.bj.pfpro.firewall.Scrub
 */
public class ScrubPanel extends PfPanel {
	
	public ScrubPanel(Firewall firewall) {
		super(firewall, new ScrubTableModel(firewall));
		
		// Layout
		this.setMinimumSize(new Dimension(200, 150));
		
		// Label and Toolbar
		this.add(new JLabel("Scrub", JLabel.CENTER));
		this.add(new BasicToolBar(this));
		
		// Handle Direction Editor
		String[] strDirection = { "in", "out" };
		getTable().getColumnModel().getColumn(0).setCellEditor(new DefaultCellEditor(new JComboBox(strDirection)));
		getTable().setRowHeight(20);		

		// Popup Menu
		getPopupMenu().add(createMenu("Add", "add"));
		getPopupMenu().add(createMenu("Remove", "del"));
		
		// Finish
		addTable();
	}

	/* (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent e) {
		if("add".equals(e.getActionCommand())) {
			((ScrubTableModel) getModel()).add();
		} else if("del".equals(e.getActionCommand())) {
			((ScrubTableModel) getModel()).remove(getTable().getSelectedRow());
		}
	}
}
