/*
 * Copyright (c) 2004, Adam VanderHook <acidos@users.sf.net>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice unmodified, this list of conditions, and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.bj.pfpro.gui.swing.table;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Vector;

import javax.swing.AbstractCellEditor;
import javax.swing.JList;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.JPopupMenu;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.table.TableCellEditor;

import net.bj.pfpro.gui.swing.PopupListener;

/**
 * Allows for manipulation of <code>Vector</code> objects rendered in
 * Swing components.
 * 
 * @author acidos
 * @version $Id: VectorCellEditor.java,v 1.2 2004/08/25 00:49:27 acidos Exp $
 */
public class VectorCellEditor extends AbstractCellEditor implements TableCellEditor, ActionListener {
	
	private Vector data;
	private JList component;

	/*
	 *  (non-Javadoc)
	 * @see javax.swing.table.TableCellEditor#getTableCellEditorComponent(javax.swing.JTable, java.lang.Object, boolean, int, int)
	 */
	public Component getTableCellEditorComponent(JTable table, Object value, boolean isSelected, int row, int column) {
		data = (Vector)value;
		component = new JList(data);
		
		JPopupMenu menu = new JPopupMenu();
		JMenuItem menuItem = null;
		
		menuItem = new JMenuItem("Add...");
		menuItem.setActionCommand("add");
		menuItem.addActionListener(this);
		menu.add(menuItem);
		
		menuItem = new JMenuItem("Remove");
		menuItem.setActionCommand("del");
		menuItem.addActionListener(this);
		menu.add(menuItem);
		
		component.add(menu);
		component.addMouseListener(new PopupListener(menu));
		
		return new JScrollPane(component);
	}

	/* (non-Javadoc)
	 * @see javax.swing.CellEditor#getCellEditorValue()
	 */
	public Object getCellEditorValue() {
		return data;
	}
	
	public void actionPerformed(ActionEvent e) {
		if("add".equals(e.getActionCommand())) {
			String result = JOptionPane.showInputDialog(component, "Add", "Add Value", JOptionPane.QUESTION_MESSAGE);
			
			if(result != null) {
				data.addElement(result);
			}
		} else if("del".equals(e.getActionCommand())) {
			data.remove(component.getSelectedIndex());			
		} else {
			return;
		}
		
		component.setListData(data);
		fireEditingStopped();
	}

}
