/*
 * Copyright (c) 2004, Adam VanderHook <acidos@users.sf.net>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice unmodified, this list of conditions, and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.bj.pfpro.gui.swing;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.io.File;

import javax.swing.JDesktopPane;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.JSeparator;
import javax.swing.KeyStroke;

/**
 * This is the default GUI for PfPro.
 * 
 * @author acidos
 * @version $Id: MainFrame.java,v 1.4 2004/08/07 14:04:30 acidos Exp $
 */
public class MainFrame extends JFrame implements ActionListener {
	
	private JDesktopPane desktop;
	private final String VERSION;

	public MainFrame(final String VERSION) throws Exception {
		// Initial Setup
		this.VERSION = VERSION;
		setTitle("PfPro " + VERSION);
		setSize(800, 600);
		
		// Desktop Pane
		desktop = new JDesktopPane();
		setContentPane(desktop);
		
		// Menu
		JMenuBar mbMain = new JMenuBar();
		
		//// File Menu
		JMenu mnuFile = new JMenu("File");
		mnuFile.setMnemonic(KeyEvent.VK_F);
		mbMain.add(mnuFile);
		
		JMenuItem menuItem = new JMenuItem("New");
		menuItem.setMnemonic(KeyEvent.VK_N);
		menuItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_N, ActionEvent.CTRL_MASK));
		menuItem.setActionCommand("new");
		menuItem.addActionListener(this);
		mnuFile.add(menuItem);
		
		JMenuItem mnuFileOpen = new JMenuItem("Open");
		mnuFileOpen.setMnemonic(KeyEvent.VK_O);
		mnuFileOpen.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_O, ActionEvent.CTRL_MASK));
		mnuFileOpen.setActionCommand("open");
		mnuFileOpen.addActionListener(this);
		mnuFile.add(mnuFileOpen);
		
		JSeparator sepOne = new JSeparator();
		mnuFile.add(sepOne);
		
		JMenuItem mnuFileExit = new JMenuItem("Exit");
		mnuFileExit.setMnemonic(KeyEvent.VK_X);
		mnuFileExit.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_X, ActionEvent.CTRL_MASK));
		mnuFileExit.setActionCommand("exit");
		mnuFileExit.addActionListener(this);
		mnuFile.add(mnuFileExit);
		
		//// Help Menu
		JMenu mnuHelp = new JMenu("Help");
		mnuHelp.setMnemonic(KeyEvent.VK_H);
		mbMain.add(mnuHelp);
		
		JMenuItem mnuHelpAbout = new JMenuItem("About");
		mnuHelpAbout.setMnemonic(KeyEvent.VK_A);
		mnuHelpAbout.setActionCommand("about");
		mnuHelpAbout.addActionListener(this);
		mnuHelp.add(mnuHelpAbout);
		
		setJMenuBar(mbMain);
	}
	
	protected void createInternalFrame(File file) throws Exception {
		InternalFrame frame = new InternalFrame(file);
		
		frame.setVisible(true);
		desktop.add(frame);
		
		try {
			frame.setSelected(true);
		} catch(java.beans.PropertyVetoException e) {}
	}
	
	/*
	 *  (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent e) {
		if("exit".equals(e.getActionCommand())) {
			System.exit(0);
		} else if("open".equals(e.getActionCommand())) {
			JFileChooser fc = new JFileChooser();
			
			int returnVal = fc.showOpenDialog(this);
			
			if(returnVal == JFileChooser.APPROVE_OPTION) {
				File file = fc.getSelectedFile();
				
				try {
					createInternalFrame(file);
				} catch (Exception e1) {
					// TODO REDO
					//JOptionPane.showMessageDialog("Exception while opening file.  Check stderr.", "File->Open Error", JOptionPane.ERROR_MESSAGE);
					e1.printStackTrace();
				}
			}
		} else if("about".equals(e.getActionCommand())) {
			String msg[] = {
				"PfPro v" + VERSION,
				"http://pfpro.bandwidth-junkies.net/",
				"by: Adam VanderHook <acidos@bandwidth-junkies.net>"
			};
			
			JOptionPane.showMessageDialog(this, msg);
		} else if("new".equals(e.getActionCommand())) {
			try {
				createInternalFrame(null);
			} catch(Exception e2) {
				JOptionPane.showMessageDialog(this, "Exception while creating new configuration/display.  Check stderr.", "File->New Error", JOptionPane.ERROR_MESSAGE);
				e2.printStackTrace();
			}
		}
	}

}
