/*
 * Copyright (c) 2004, Adam VanderHook <acidos@users.sf.net>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice unmodified, this list of conditions, and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.bj.pfpro.gui.swing.table;

import java.util.Enumeration;
import java.util.Vector;

import javax.swing.table.AbstractTableModel;

import net.bj.pfpro.firewall.Firewall;

/**
 * A base model for displaying <code>Firewall</code> information.
 *  * 
 * @author acidos
 * @version $Id: FirewallTableModel.java,v 1.5.4.1 2004/09/13 23:28:39 acidos Exp $
 */
public class FirewallTableModel extends AbstractTableModel {

	/**
	 * An array of column names
	 */
	protected String[] cNames;

	private Firewall firewall;

	/**
	 * Default constructor.
	 * 
	 * @param firewall	The <code>Firewall</code> object to work with
	 * @param cNames	Column names, in order
	 */
	public FirewallTableModel(Firewall firewall, String[] cNames) {
		this.firewall = firewall;
		this.cNames = cNames;
	}

	/**
	 * Given a string, returns a <code>null</code> if the value is "",
	 * otherwise returns the string.
	 *
	 * @param	obj The string to examine
	 * @return	String Null; or the Object representation of the string.
	 */
	protected String getStringValue(Object obj) {
		String result = null;
		String str = (String)obj;

		if(!str.equals("")){
			result = str; 
		}

		return result;
	}
	
	/**
	 * Converts an <code>Object</code> to a primative type <code>int</code>.
	 * While you can plug a primative into a <code>Vector</code>, you can
	 * only retreive a <code>Object</code>, and casting back to a primative
	 * is very nasty to have to do repeatedly.
	 * 
	 * @param obj	Object to cast to primative <code>int</code>
	 * @return	The <code>int</code> value of the supplied <code>Object</code>
	 */
	protected int getIntValue(Object obj) {
		return (Integer.valueOf(String.valueOf(obj))).intValue();
	}
	
	/**
	 * Generates a <code>java.util.Vector</code> from a
	 * given <code>Enumeration</code>
	 * 
	 * @param enum	Enumeration to be transformed
	 * @return	Vector
	 */
	protected Vector getVectorValue(Enumeration enum) {
		Vector result = new Vector();
		
		while(enum.hasMoreElements()) {
			result.add(enum.nextElement());
		}
		
		return result;
	}

	
	/*
	 *  (non-Javadoc)
	 * @see javax.swing.table.TableModel#getColumnName(int)
	 */
	public String getColumnName(int col) {
		return cNames[col];
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#getColumnCount()
	 */
	public int getColumnCount() {
		return cNames.length;
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#isCellEditable(int, int)
	 */
	public boolean isCellEditable(int row, int col) {
		return true;
	}

	/*
	 *  (non-Javadoc)
	 * @see javax.swing.table.TableModel#getColumnClass(int)
	 */
	public Class getColumnClass(int c) {
		return getValueAt(0, c).getClass();
	}

	/*
	 *  (non-Javadoc)
	 * @see javax.swing.table.TableModel#getValueAt(int, int)
	 */
	public Object getValueAt(int row, int col) {
		return new String("ERR");
	}

	/*
	 *  (non-Javadoc)
	 * @see javax.swing.table.TableModel#getRowCount()
	 */
	public int getRowCount() {
		return 0;
	}

	/**
	 * Returns the <code>Firewall</code> stored by the <code>TableModel</code>
	 * 
	 * @return	Firewall
	 */
	public Firewall getFirewall() {
		return firewall;
	}

}
