/*
 * Copyright (c) 2004, Adam VanderHook <acidos@users.sf.net>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice unmodified, this list of conditions, and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.bj.pfpro.gui.swing.table;

import net.bj.pfpro.firewall.Firewall;
import net.bj.pfpro.firewall.Macro;

/**
 * Handles working with Macro elements from a DOM object according to
 * firewall.dtd.
 * 
 * @author acidos
 * @version $Id: MacroTableModel.java,v 1.3 2004/07/28 23:01:52 acidos Exp $
 */
public class MacroTableModel extends FirewallTableModel {

	final static String[] COL_NAMES = { 
		"Name",
		"Value"
	};

	/**
	 * Creates a <code>MacroTableModel</code> from the specified DOM Document.
	 * 
	 * @param firewall	The firewall with macros wished to be handled.
	 */
	public MacroTableModel(Firewall firewall) {
		super(firewall, COL_NAMES);
	}
	
	/**
	 * Creates a new, empty macro.
	 */
	public void add() {
		Macro newMacro = new Macro();
		newMacro.setName("");
		newMacro.setValue("");
		getFirewall().addMacro(newMacro);
		
		fireTableRowsInserted(0, getRowCount());
	}
	
	/**
	 * Removes the macro at the specified row.
	 * 
	 * @param row	Macro to delete.
	 */
	public void remove(int row) {
		getFirewall().removeMacro(row);
		
		fireTableRowsDeleted(row, row);
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#getRowCount()
	 */
	public int getRowCount() {
		return getFirewall().getMacroCount();
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#getValueAt(int, int)
	 */
	public Object getValueAt(int rowIndex, int columnIndex) {
		Macro result = getFirewall().getMacro(rowIndex);

		if(getColumnName(columnIndex).equals("Name")) {
			return result.getName();
		} else if(getColumnName(columnIndex).equals("Value")) {
			return result.getValue();
		}

		return new String("UNKNOWN COLUMN");
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#setValueAt(java.lang.Object, int, int)
	 */
	public void setValueAt(Object newValue, int rowIndex, int columnIndex) {
		Macro result = getFirewall().getMacro(rowIndex);

		if(getColumnName(columnIndex).equals("Name")) {
			result.setName((String)newValue);
		} else if(getColumnName(columnIndex).equals("Value")) {
			result.setValue((String)newValue);
		}
	}

}
