/*
 * Copyright (c) 2004, Adam VanderHook <acidos@users.sf.net>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice unmodified, this list of conditions, and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.bj.pfpro.gui.swing.table;

import net.bj.pfpro.firewall.Firewall;
import net.bj.pfpro.firewall.Scrub;

/**
 * Acts as a <code>TableModel</code> for DOM objects conforming to firewall.dtd
 * 
 * @author acidos
 * @version $Id: ScrubTableModel.java,v 1.2 2004/07/28 23:01:52 acidos Exp $
 */
public class ScrubTableModel extends FirewallTableModel {
	
	private static final String[] CNAMES = { "Direction", "Random-ID", "No-DF", "Max-MSS" };

	/**
	 * Creates a <code>NormalizationTableModel</code> from the specified DOM Document.
	 * 
	 * @param firewall		DOM Document of firewall
	 */
	public ScrubTableModel(Firewall firewall) {
		super(firewall, CNAMES);
	}
	
	/*
	 *  (non-Javadoc)
	 * @see javax.swing.table.TableModel#getValueAt(int, int)
	 */
	public Object getValueAt(int rowIndex, int columnIndex) {
		Scrub scrub = getFirewall().getScrub(rowIndex);

		Object result = null;

		if(getColumnName(columnIndex).equals("Direction")) {
			result = scrub.getDirection();
		} else if(getColumnName(columnIndex).equals("Random-ID")) {
			result = new Boolean(scrub.getRandomid());
		} else if(getColumnName(columnIndex).equals("No-DF")) {
			result = new Boolean(scrub.getNodf());
		} else if(getColumnName(columnIndex).equals("Max-MSS")) {
			result = new Integer(scrub.getMaxmss());
		}

		return result;
	}
	
	/**
	 * Creates a new scrub rule
	 */
	public void add() {
		Scrub scrub = new Scrub();
		scrub.setDirection("");
		getFirewall().addScrub(scrub);
		
		fireTableRowsInserted(0, getRowCount());
	}
	
	/**
	 * Removes the scrub rule from the specified row.
	 * 
	 * @param row	The row index of the scrub rule to be removed.
	 */
	public void remove(int row) {
		getFirewall().removeScrub(row);
		
		fireTableRowsDeleted(row, row);
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#getRowCount()
	 */
	public int getRowCount() {
		return getFirewall().getScrubCount();
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#setValueAt(java.lang.Object, int, int)
	 */
	public void setValueAt(Object newValue, int rowIndex, int columnIndex) {
		Scrub scrub = getFirewall().getScrub(rowIndex);

		if(getColumnName(columnIndex).equals("Direction")) {
			scrub.setDirection((String)newValue);
		} else if(getColumnName(columnIndex).equals("Random-ID")) {
			scrub.setRandomid(((Boolean)newValue).booleanValue());
		} else if(getColumnName(columnIndex).equals("No-DF")) {
			scrub.setNodf(((Boolean)newValue).booleanValue());
		} else if(getColumnName(columnIndex).equals("Max-MSS")) {
			scrub.setMaxmss(((Integer)newValue).intValue());
		}
	}

}
