/*
 * Copyright (c) 2004, Adam VanderHook <acidos@users.sf.net>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice unmodified, this list of conditions, and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.bj.pfpro.gui.swing.toolbar;

import java.awt.event.ActionListener;
import java.net.URL;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JToolBar;

/**
 * A basic toolbar to be housed inside an InternalFrame.
 * 
 * @author acidos
 * @version $Id: PfToolBar.java,v 1.1 2004/08/08 01:36:45 acidos Exp $
 */
public class PfToolBar extends JToolBar {
	
	private ActionListener parent;
	
	/**
	 * Creates a toolbar for use inside an <code>InternalFrame</code>.
	 * 
	 * @param parent	The <code>InternalFrame</code> that will contain the toolbar.
	 * @see net.bj.pfpro.gui.swing.InternalFrame
	 */
	public PfToolBar(ActionListener parent) {
		this.parent = parent;
		
		setRollover(true);
	}
	
	/**
	 * Constructs a JButton for use in a toolbar.
	 * 
	 * @param imageName			Path of the image to use as the button's icon
	 * @param actionCommand		Action command sent by the button
	 * @param toolTipText		Tool tip help text
	 * @param altText			Text of the button of the image cannot be loaded
	 * 
	 * @return					The constructed button
	 */
	protected JButton getButton(String imageName, String actionCommand, String toolTipText, String altText) {
		JButton button = new JButton();
		
		// Look for the image
		String imgLocation = imageName + "16.gif";
		URL imageURL = getClass().getResource(imgLocation);
		
		// Create and initialize the button
		button.setActionCommand(actionCommand);
		button.setToolTipText(toolTipText);
		button.addActionListener(getParentObject());
			
		if(imageURL != null) {									// image found!
			button.setIcon(new ImageIcon(imageURL, altText));
		} else {												// dude, where's my image?
			button.setText(altText);
		}
		
		return button;
	}

	/**
	 * Retreive the instance of <code>InternalFrame</code> that is housing this
	 * toolbar.
	 * 
	 * @return		The <code>InternalFrame</code> that is housing the toolbar.
	 */
	public ActionListener getParentObject() {
		return parent;
	}

}
